Django Television
=================

``django-television`` is a small library wrapping most of the configuration required for Channels through the use of simple Python decorators.

Visit `Github <https://github.com/pztrick/django-television/>`_ for further documentation.